<?php
/**
 * @copyright	Copyright (c) 2014 Skyline Technology Ltd (http://extstore.com). All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

// No direct access.
defined('_JEXEC') or die;

/**
 * ExtStore Mood Poll Component - Mood Table Class.
 *
 * @package		Joomla.Administrator
 * @subpakage	ExtStore.MoodPoll
 */
class MoodPollTableMood extends JTable {

	/**
	 * Constructor.
	 *
	 * @param	JDatabase	A database connector object.
	 */
	public function __construct(&$db) {
		parent::__construct('#__moodpoll_moods', 'id', $db);
	}

	/**
	 * Overloaded bind function to pre-process the params.
	 *
	 * @param	array		Named array
	 * @return	null|string	null is operation was satisfactory, otherwise returns an error.
	 * @see		JTable:bind
	 */
	public function bind($array, $ignore = '') {
		if (isset($array['params']) && is_array($array['params'])) {
			$registry			= new JRegistry();
			$registry->loadArray($array['params']);
			$array['params']	= (string) $registry;
		}

		return parent::bind($array, $ignore);
	}

	/**
	 * Overload the store method for the Mood table.
	 *
	 * @param	boolean	Toggle whether null values should be updated.
	 * @return	boolean	True on success, false on failure.
	 */
	public function store($updateNulls = false) {
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();

		if ($this->id) {
			// Existing item
		} else {

		}


		// Attempt to store the user data.
		return parent::store($updateNulls);
	}

	/**
	 * Overloaded check method to ensure data integrity.
	 *
	 * @return	boolean		True on success.
	 */
	public function check() {
		// check for valid name
		if (trim($this->title) == '') {
			$this->setError(JText::_('COM_MOODPOLL_MOOD_ERROR_TABLES_TITLE'));
			return false;
		}

		// check for valid image
		if (trim($this->image) == '') {
			$this->setError(JText::_('COM_MOODPOLL_MOOD_ERROR_TABLES_IMAGE'));
			return false;
		}

		// check for existing name
		$query = 'SELECT id'
				. ' FROM #__moodpoll_moods'
				. ' WHERE title = ' . $this->_db->quote($this->title)
		;
		$this->_db->setQuery($query);

		$xid	= intval($this->_db->loadResult());
		if ($xid && $xid != intval($this->id)) {
			$this->setError(JText::_('COM_MOODPOLL_MOOD_ERROR_TABLES_NAME'));
			return false;
		}

		return true;
	}

	/**
	 * Method to set the publishing state for a row or list of rows in the database
	 * table. The method respects checked out rows by other users and will attempt
	 * to checkin rows that it can after adjustments are made.
	 *
	 * @param	mixed	An optional array of primary key values to update. If not
	 * 					set the instance property value is used.
	 * @param	int		The publishing state. eg. [0 = unpublished, 1 = published]
	 * @param	int		The user id of the user performing the operation.
	 * @return	bool	True on success.
	 */
	public function publish($pks = null, $state = 1, $userId = 0) {
		// Initialize variables.
		$k = $this->_tbl_key;

		// Sanitize input.
		JArrayHelper::toInteger($pks);
		$userId		= (int) $userId;
		$state		= (int) $state;

		// If there are no primary keys set check to see if the instance key is set.
		if (empty($pks)) {
			if ($this->$k) {
				$pks	= array($this->$k);
			} else {
				$this->setError(JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED'));
				return false;
			}
		}

		// Build the WHERE clause for the primary keys.
		$where	= $k . ' = ' . implode(' OR ' . $k . ' = ', $pks);

		// Determine if there is checkin support for the table.
		if (!property_exists($this, 'checked_out') || !property_exists($this, 'checked_out_time')) {
			$checkin	= '';
		} else {
			$checkin	= ' AND (checked_out = 0 OR checked_out = ' . (int) $userId . ')';
		}

		// UPdate the publishing state for rows with the given primary keys.
		$query = 'UPDATE `' . $this->_tbl . '`'
				. ' SET `state` = ' . (int) $state
				. ' WHERE (' . $where . ')'
				. $checkin
		;
		$this->_db->setQuery($query);

		try {
			$this->_db->execute();
		} catch (RuntimeException $e) {
			$this->setError($e->getMessage());
			return false;
		}

		// Check for a database error.
		if ($this->_db->getErrorNum()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// If checkin is supported and all rows were adjusted, check them in.
		if ($checkin && (count($pks) == $this->_db->getAffectedRows())) {
			// Checkin the rows.
			foreach ($pks as $pk) {
				$this->checkin($pk);
			}
		}

		// If the JTable instance value is in the list of primary keys that were set, set the instance.
		if (in_array($this->$k, $pks)) {
			$this->state = $state;
		}

		$this->setError('');
		return true;
	}
}