<?php
/**
 * @copyright	Copyright (c) 2014 Skyline Technology Ltd (http://extstore.com). All rights reserved.
 * @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

// no direct access
defined('_JEXEC') or die;

/**
 * ExtStore - Mood Poll Helper Class.
 *
 * @package		Joomla.Site
 * @subpakage	ExtStore.MoodPoll
 */
class modMoodPollHelper {

	public static function getModel($params) {
		JModelLegacy::addIncludePath(JPATH_ROOT . '/modules/mod_moodpoll/models');
		$model		= JModelLegacy::getInstance('Moods', 'MoodPollModel', array('ignore_request' => true));

		$moodIds	= $params->get('mood_ids', array());

		if (count($moodIds)) {
			$model->setState('filter.mood_id', $moodIds);
		}

		return $model;
	}

	/**
	 * Ajax vote.
	 */
	public static function voteAjax() {
		$app	= JFactory::getApplication();
		$db		= JFactory::getDbo();

		// get module params
		$moduleId	= $app->input->get('module_id');

		if (!$moduleId) {
			return '';
		}

		$query	= $db->getQuery(true);

		$query->select('params')
			->from('#__modules')
			->where('id = ' . $moduleId)
			->where('module = ' . $db->q('mod_moodpoll'))
		;
		$db->setQuery($query);

		$params	= $db->loadResult();

		if (!$params) {
			return '';
		}

		$params		= new JRegistry($params);

		// get the model
		$model		= self::getModel($params);
		$moodId		= $app->input->get('mood_id');

		// check if user can vote
		$checkPerm	= $model->checkPermission($moodId);

		if ($checkPerm != -1) {
			return '';
		}

		// vote
		$result	= $model->vote($moodId);

		if (!$result) {
			return '';
		}

		// return result html
		$id				= $moduleId;
		$items			= $model->getItems();
		$checkPerm		= $model->checkPermission();
		$totalVotes		= $model->getTotalVotes();
		$chosenMood		= $model->getChosenMood();

		if (!$chosenMood) {
			return '';
		}

		// get random message
		$messages	= explode(PHP_EOL, $chosenMood->message);
		$message	= $messages[rand(0, count($messages) - 1)];

		// load language
		$lang	= JFactory::getLanguage();
		$lang->load('mod_moodpoll');

		$layout		= $params->get('layout', 'default');

		ob_start();
		require JModuleHelper::getLayoutPath('mod_moodpoll', $layout);
		$contents	= ob_get_contents();
		ob_end_clean();

		return $contents;
	}

	/**
	 * Generate custom CSS.
	 */
	public static function generateStyle($id, $params) {
		$moodWidth			= (int) $params->get('mood_width', 50);
		$chosenMoodWidth	= (int) $params->get('chosen_mood_width', 150);
		$selectColor		= $params->get('selected_color', '#53a9ff');
		$lineColor			= $params->get('line_color', '#aaaaaa');
		$backgroundColor	= $params->get('background_color');
		$textColor			= $params->get('text_color');
		$customCss			= $params->get('custom_css');

		$style				= "
			$id ul li.moodpoll-image img,
			$id ul li.moodpoll-result-image img {
				width: {$moodWidth}px;
			}

			$id .moodpoll-chosen-mood img {
				width: {$chosenMoodWidth}px;
			}

			$id li.moodpoll-image.mood-selected img,
			$id li.moodpoll-image img:hover {
				-webkit-box-shadow : 0px 0px 3px 2px $selectColor;
				-moz-box-shadow : 0px 0px 3px 2px $selectColor;
				box-shadow : 0px 0px 3px 2px $selectColor;
			}

			.moodpoll > .moodpoll-form + .moodpoll-result {
				border-top-color: $lineColor;
			}
		";

		if ($backgroundColor || $textColor) {
			$style		.= "\n$id {";

			if ($backgroundColor) {
				$style	.= "\nbackground-color: $backgroundColor;";
			}

			if ($textColor) {
				$style	.= "\ncolor: $textColor;";
			}

			$style		.= "\n}";
		}

		JFactory::getDocument()->addStyleDeclaration($style . $customCss);
	}
}